@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Config;
 # ABSTRACT: Load config files for Authentication Milter
 use strict;
 use warnings;
-our $VERSION = '2.20180903'; # VERSION
+our $VERSION = '2.20180912'; # VERSION
 
 use Mail::Milter::Authentication;
 use Module::Load;
@@ -154,12 +154,12 @@ sub get_config {
         opendir $dh, $folder;
         my @config_files =
             sort
-            grep { $_ =~ /\.[json|toml]$/ }
+            grep { $_ =~ /\.(json|toml)$/ }
             grep { not $_ =~ /^\./ }
             readdir($dh);
         closedir $dh;
         foreach my $file ( @config_files ) {
-            $file =~ /(^.*)\.[json|toml]$/;
+            $file =~ /(^.*)\.(json|toml)$/;
             my $handler = $1;
             ## ToDo Consider what to do if config already exists in .json config
             $config->{'handlers'}->{$handler} = load_file( join( '/', $folder, $file ) );
@@ -210,7 +210,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 2.20180903
+version 2.20180912
 
 =head1 SYNOPSIS
 
